decode_html_entities

Function decode_html_entities 

pub fn decode_html_entities<S: ?Sized + AsRef<str>>(text: &S) -> Cow<'_, str>
Decode HTML entities in a given string.

Only exact named and numeric character references ending with ; are decoded. Invalid Unicode scalar values, null, and C0 controls other than ASCII whitespace are left unchanged. This function does not implement legacy semicolonless references or C1 control replacements.