decode_html_entities_to_vec

Function decode_html_entities_to_vec 

pub fn decode_html_entities_to_vec<S: AsRef<str>>(
    text: S,
    output: &mut Vec<u8>,
) -> &[u8] 
Decode HTML entities in a given string to a mutable Vec<u8> reference and return the decoded data slice.

Only exact named and numeric character references ending with ; are decoded. Invalid Unicode scalar values, null, and C0 controls other than ASCII whitespace are left unchanged. This function does not implement legacy semicolonless references or C1 control replacements.