decode_html_entities_to_string

Function decode_html_entities_to_string 

pub fn decode_html_entities_to_string<S: AsRef<str>>(
    text: S,
    output: &mut String,
) -> &str
Decode HTML entities in a given string to a mutable String reference and return the decoded string slice.

Only exact named and numeric character references ending with ; are decoded. Invalid Unicode scalar values, null, and C0 controls other than ASCII whitespace are left unchanged. This function does not implement legacy semicolonless references or C1 control replacements.